summaryrefslogtreecommitdiffstats
path: root/lib/compatibility/kmdi/qextmdi/kmdichildview.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-16 19:02:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-16 19:02:47 +0000
commite985f7e545f4739493965aad69bbecb136dc9346 (patch)
tree54afd409d8acd6202dd8ab611d24e78c28e4c0a0 /lib/compatibility/kmdi/qextmdi/kmdichildview.h
parentf7670c198945adc3b95ad69a959fe5f8ae55b493 (diff)
downloadtdewebdev-e985f7e545f4739493965aad69bbecb136dc9346.tar.gz
tdewebdev-e985f7e545f4739493965aad69bbecb136dc9346.zip
TQt4 port kdewebdev
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdewebdev@1237029 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/compatibility/kmdi/qextmdi/kmdichildview.h')
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdichildview.h49
1 files changed, 25 insertions, 24 deletions
diff --git a/lib/compatibility/kmdi/qextmdi/kmdichildview.h b/lib/compatibility/kmdi/qextmdi/kmdichildview.h
index 656c17fd..298b2198 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdichildview.h
+++ b/lib/compatibility/kmdi/qextmdi/kmdichildview.h
@@ -6,8 +6,8 @@
// begin : 07/1999 by Szymon Stefanek as part of kvirc
// (an IRC application)
// changes : 09/1999 by Falk Brettschneider to create an
-// - 06/2000 stand-alone Qt extension set of
-// classes and a Qt-based library
+// - 06/2000 stand-alone TQt extension set of
+// classes and a TQt-based library
// 2000-2003 maintained by the KDevelop project
// patches : 02/2000 by Massimo Morin (mmorin@schedsys.com)
// */2000 by Lars Beikirch (Lars.Beikirch@gmx.net)
@@ -49,7 +49,7 @@ class KMdiChildViewPrivate;
*
* All such windows 'lives' attached to a KMdiChildFrm widget
* managed by KMdiChildArea, or detached (managed by the window manager.)
* So remember that the KMdiChildView::parent pointer may change, and may be 0L, too.
*
* There are 2 possibilities for you to put your widgets under MDI control:
*
@@ -71,14 +71,14 @@ class KMdiChildViewPrivate;
* KMdiChildView* pMDICover = new KMdiChildView( pNewView->caption());
* pMDICover->setIcon(icon);
* m_MDICoverList.append( pMDICover);
- * TQBoxLayout* pLayout = new TQHBoxLayout( pMDICover, 0, -1, "layout");
+ * TQBoxLayout* pLayout = new TQHBoxLayout( pMDICover, 0, -1, "tqlayout");
* pNewView->reparent( pMDICover, TQPoint(0,0));
* pLayout->addWidget( pNewView);
* pMDICover->setName( pNewView->name());
* // captions
* TQString shortName = pNewView->caption();
* int length = shortName.length();
- * shortName = shortName.right(length - (shortName.findRev('/') +1));
+ * shortName = shortName.right(length - (shortName.tqfindRev('/') +1));
* pMDICover->setTabCaption( shortName);
* pMDICover->setCaption(pNewView->caption());
*
@@ -105,11 +105,12 @@ class KMdiChildViewPrivate;
*
*/
-class KMDI_EXPORT KMdiChildView : public QWidget
+class KMDI_EXPORT KMdiChildView : public TQWidget
{
friend class KMdiMainFrm;
friend class KMdiChildFrm;
Q_OBJECT
+ TQ_OBJECT
// attributes
protected:
@@ -182,13 +183,13 @@ public:
/**
* Constructor
*/
- KMdiChildView( const TQString& caption, TQWidget* parentWidget = 0L, const char* name = 0L, WFlags f = 0 );
+ KMdiChildView( const TQString& caption, TQWidget* tqparentWidget = 0L, const char* name = 0L, WFlags f = 0 );
/**
* Constructor
* sets "Unnamed" as default caption
*/
- KMdiChildView( TQWidget* parentWidget = 0L, const char* name = 0L, WFlags f = 0 );
+ KMdiChildView( TQWidget* tqparentWidget = 0L, const char* name = 0L, WFlags f = 0 );
/**
* Destructor
@@ -253,7 +254,7 @@ public:
virtual void setMDICaption( const TQString &caption );
/**
* Returns the KMdiChildFrm parent widget (or 0 if the window is not attached)
*/
KMdiChildFrm *mdiParent() const;
@@ -270,28 +271,28 @@ public:
bool isMaximized() const;
/**
- * Returns the geometry of this MDI child window as TQWidget::geometry() does.
+ * Returns the tqgeometry of this MDI child window as TQWidget::tqgeometry() does.
*/
TQRect internalGeometry() const;
/**
- * Sets the geometry of the client area of this MDI child window. The
+ * Sets the tqgeometry of the client area of this MDI child window. The
* top left position of the argument is the position of the top left point
* of the client area in its parent coordinates and the arguments width
* and height is the width and height of the client area. Please note: This
* differs from the behavior of TQWidget::setGeometry()!
*/
void setInternalGeometry( const TQRect& newGeomety );
/**
* Returns the frame geometry of this window or of the parent if there is any...
*/
TQRect externalGeometry() const;
/**
- * Sets the geometry of the frame of this MDI child window. The top left
+ * Sets the tqgeometry of the frame of this MDI child window. The top left
* position of the argument is the position of the top left point of the
* frame in its parent coordinates and the arguments width and height is
* the width and height of the widget frame. Please note: This differs
* from the behavior of TQWidget::setGeometry()!
*/
@@ -315,12 +316,12 @@ public:
virtual void maximize( bool bAnimate );
/**
- * Returns the geometry that will be restored by calling restore().
+ * Returns the tqgeometry that will be restored by calling restore().
*/
TQRect restoreGeometry();
/**
- * Sets the geometry that will be restored by calling restore().
+ * Sets the tqgeometry that will be restored by calling restore().
*/
void setRestoreGeometry( const TQRect& newRestGeo );
@@ -358,7 +359,7 @@ public:
*/
inline void updateTimeStamp()
{
- m_time.setDate( TQDate::currentDate() );
+ m_time.setDate( TQDate::tqcurrentDate() );
m_time.setTime( TQTime::currentTime() );
}
@@ -424,17 +425,17 @@ public slots:
virtual void slot_clickedInDockMenu();
/**
* Calls TQWidget::show but also for it's parent widget if attached
*/
virtual void show();
/**
* Calls TQWidget::hide() or it's parent widget hide() if attached
*/
virtual void hide();
/**
* Calls TQWidget::raise() or it's parent widget raise() if attached
*/
virtual void raise();
@@ -465,7 +466,7 @@ protected:
virtual void closeEvent( TQCloseEvent *e );
/**
- * It only catches TQEvent::KeyPress events there. If a Qt::Key_Tab is pressed, the internal MDI focus
+ * It only catches TQEvent::KeyPress events there. If a TQt::Key_Tab is pressed, the internal MDI focus
* handling is called. That means if the last focusable child widget of this is called, it will jump to the
* first focusable child widget of this.
* See KMdiChildView::setFirstFocusableChildWidget and KMdiChildView::lastFirstFocusableChildWidget
@@ -603,7 +604,7 @@ private:
inline KMdiChildFrm *KMdiChildView::mdiParent() const
{
- TQWidget * pw = parentWidget();
+ TQWidget * pw = tqparentWidget();
if ( pw != 0L )
if ( pw->inherits( "KMdiChildFrm" ) )
return ( KMdiChildFrm * ) pw;
@@ -612,4 +613,4 @@ inline KMdiChildFrm *KMdiChildView::mdiParent() const
#endif //_KMDICHILDVIEW_H_
-// kate: space-indent off; replace-tabs off; indent-mode csands; tab-width 4;
+// kate: space-indent off; tqreplace-tabs off; indent-mode csands; tab-width 4;
@@ -49,7 +49,7 @@ class KMdiChildViewPrivate;
* All such windows 'lives' attached to a KMdiChildFrm widget
* managed by KMdiChildArea, or detached (managed by the window manager.)
- * So remember that the KMdiChildView::parent pointer may change, and may be 0L, too.
+ * So remember that the KMdiChildView::tqparent pointer may change, and may be 0L, too.
*
* There are 2 possibilities for you to put your widgets under MDI control:
@@ -253,7 +254,7 @@ public:
virtual void setMDICaption( const TQString &caption );
/**
- * Returns the KMdiChildFrm parent widget (or 0 if the window is not attached)
+ * Returns the KMdiChildFrm tqparent widget (or 0 if the window is not attached)
*/
KMdiChildFrm *mdiParent() const;
@@ -270,28 +271,28 @@ public:
* top left position of the argument is the position of the top left point
- * of the client area in its parent coordinates and the arguments width
+ * of the client area in its tqparent coordinates and the arguments width
* and height is the width and height of the client area. Please note: This
* differs from the behavior of TQWidget::setGeometry()!
@@ -270,28 +271,28 @@ public:
void setInternalGeometry( const TQRect& newGeomety );
/**
- * Returns the frame geometry of this window or of the parent if there is any...
+ * Returns the frame tqgeometry of this window or of the tqparent if there is any...
*/
TQRect externalGeometry() const;
@@ -270,28 +271,28 @@ public:
* position of the argument is the position of the top left point of the
- * frame in its parent coordinates and the arguments width and height is
+ * frame in its tqparent coordinates and the arguments width and height is
* the width and height of the widget frame. Please note: This differs
* from the behavior of TQWidget::setGeometry()!
@@ -424,17 +425,17 @@ public slots:
virtual void slot_clickedInDockMenu();
/**
- * Calls TQWidget::show but also for it's parent widget if attached
+ * Calls TQWidget::show but also for it's tqparent widget if attached
*/
virtual void show();
@@ -424,17 +425,17 @@ public slots:
virtual void show();
/**
- * Calls TQWidget::hide() or it's parent widget hide() if attached
+ * Calls TQWidget::hide() or it's tqparent widget hide() if attached
*/
virtual void hide();
@@ -424,17 +425,17 @@ public slots:
virtual void hide();
/**
- * Calls TQWidget::raise() or it's parent widget raise() if attached
+ * Calls TQWidget::raise() or it's tqparent widget raise() if attached
*/
virtual void raise();